@@ -16,4 +16,23 @@
 # ##### END GPL LICENSE BLOCK #####
 
 scene = None
-object = None
\ No newline at end of file
+object = None
+
+selectable_objects = []
+selected_bones = []
+selected_editable_bones = []
+selected_editable_fcurves = []
+selected_editable_objects = []
+selected_editable_sequences = []
+selected_nla_strips = []
+selected_objects = []
+selected_pose_bones = []
+selected_pose_bones_from_active_object = []
+selected_sequences = []
+selected_visible_fcurves = []
+
+class preferences:
+    class addons:
+        def get(key, default=None):
+            pass
+        
\ No newline at end of file
